@@ -11,9 +11,12 @@
 #ifdef HEADER
 
 typedef struct qrpng {
+    /* Size of a module in pixels. */
     unsigned int scale;
+    /* Size of the quietzone in modules. */
     unsigned int quietzone;
     char * filename;
+    /* PNG stuff. */
     png_structp png;
     png_infop info; 
     png_byte ** row_pointers;
@@ -31,6 +34,14 @@ typedef enum qrpng_status {
 qrpng_status_t;
 
 #define QUIETZONE 4
+#define MAX_SCALE 100
+#define MAX_QUIETZONE 100
+#define QRPNG_DEFAULT_QUIET QUIETZONE
+#define QRPNG_MINIMUM_QUIET 0
+#define QRPNG_MAXIMUM_QUIET 100
+#define QRPNG_DEFAULT_SCALE 3
+#define QRPNG_MINIMUM_SCALE 1
+#define QRPNG_MAXIMUM_SCALE MAX_SCALE
 
 #endif /* def HEADER */
 
@@ -38,8 +49,6 @@ qrpng_status_t;
 
 #define SETBIT(f,x) f[((x)>>3)] |= 0x80 >> ((x) & 7)
 
-#define MAX_SCALE 100
-#define MAX_QUIETZONE 100
 
 qrpng_status_t
 qrpng_make_png (qr_t * qr, qrpng_t * qrpng)
